@@ -1,40 +1,55 @@
 #!/usr/bin/env python
 # -*- mode: python; coding: utf-8; -*-
-##---------------------------------------------------------------------------##
-##
-## Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
-## Copyright (C) 2003 Mt. Hood Playing Card Co.
-## Copyright (C) 2005-2009 Skomoroh
-##
-## This program is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## This program is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with this program.  If not, see <http://www.gnu.org/licenses/>.
-##
-##---------------------------------------------------------------------------##
-
-__all__ = []
+# ---------------------------------------------------------------------------##
+#
+# Copyright (C) 1998-2003 Markus Franz Xaver Johannes Oberhumer
+# Copyright (C) 2003 Mt. Hood Playing Card Co.
+# Copyright (C) 2005-2009 Skomoroh
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# ---------------------------------------------------------------------------##
 
 # imports
 
 # PySol imports
 from pysollib.gamedb import registerGame, GameInfo, GI
-from pysollib.util import *
-from pysollib.stack import *
 from pysollib.game import Game
 from pysollib.layout import Layout
-from pysollib.hint import AbstractHint, DefaultHint, CautiousDefaultHint
-from pysollib.pysoltk import MfxCanvasText
+from pysollib.hint import DefaultHint, CautiousDefaultHint
 
-from gypsy import DieRussische_Foundation
+from pysollib.games.gypsy import DieRussische_Foundation
+
+from pysollib.util import ACE, ANY_RANK, ANY_SUIT, KING, NO_RANK, \
+        UNLIMITED_MOVES, UNLIMITED_REDEALS
+
+from pysollib.stack import \
+        AC_FoundationStack, \
+        AC_RowStack, \
+        BO_RowStack, \
+        RK_FoundationStack, \
+        RK_RowStack, \
+        ReserveStack, \
+        SS_FoundationStack, \
+        SS_RowStack, \
+        Spider_SS_RowStack, \
+        Stack, \
+        TalonStack, \
+        UD_AC_RowStack, \
+        WasteStack, \
+        WasteTalonStack, \
+        StackWrapper
 
 
 # ************************************************************************
@@ -65,7 +80,8 @@ class FortyThieves(Game):
     # game layout
     #
 
-    def createGame(self, max_rounds=1, num_deal=1, rows=10, playcards=12, XCARDS=64, XOFFSET=None):
+    def createGame(self, max_rounds=1, num_deal=1, rows=10,
+                   playcards=12, XCARDS=64, XOFFSET=None):
         # create layout
         if XOFFSET is None:
             l, s = Layout(self), self.s
@@ -81,20 +97,23 @@ class FortyThieves(Game):
         w1, w2 = maxrows*l.XS+l.XM, 2*l.XS
         if w2 + XCARDS * l.XOFFSET > w1:
             l.XOFFSET = int((w1 - w2) / XCARDS)
-        # (piles up to 12 cards are playable without overlap in default window size)
+        # (piles up to 12 cards are playable without overlap
+        #   in default window size)
         h = max(2*l.YS, l.YS+(playcards-1)*l.YOFFSET)
         self.setSize(w1, l.YM + l.YS + h + l.YS + l.TEXT_HEIGHT)
 
         # create stacks
         # foundations
-        x = l.XM + (maxrows - 4*decks) * l.XS / 2
+        x = l.XM + (maxrows - 4*decks) * l.XS // 2
         y = l.YM
         for i in range(4*decks):
-            s.foundations.append(self.Foundation_Class(x, y, self,
-                          suit=i/decks, max_move=self.FOUNDATION_MAX_MOVE))
+            s.foundations.append(
+                self.Foundation_Class(
+                    x, y, self,
+                    suit=i//decks, max_move=self.FOUNDATION_MAX_MOVE))
             x = x + l.XS
         # rows
-        x = l.XM + (maxrows - rows) * l.XS / 2
+        x = l.XM + (maxrows - rows) * l.XS // 2
         y = l.YM + l.YS
         for i in range(rows):
             s.rows.append(self.RowStack_Class(x, y, self,
@@ -125,9 +144,7 @@ class FortyThieves(Game):
             self.s.talon.dealRow(flip=0, frames=0)
         for i in range(self.DEAL[1] - 1):
             self.s.talon.dealRow(frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
-        self.s.talon.dealCards()          # deal first card to WasteStack
+        self._startAndDealRowAndCards()
 
     def fillStack(self, stack):
         if self.FILL_EMPTY_ROWS and stack in self.s.rows and not stack.cards:
@@ -185,6 +202,7 @@ class Lucas(WaningMoon):
 
 class NapoleonsSquare(FortyThieves):
     ROW_MAX_MOVE = UNLIMITED_MOVES
+
     def createGame(self):
         FortyThieves.createGame(self, rows=12)
 
@@ -227,6 +245,7 @@ class Josephine(FortyThieves):
 
 class MarieRose(Josephine):
     DEAL = (0, 5)
+
     def createGame(self):
         FortyThieves.createGame(self, rows=12, playcards=16, XCARDS=96)
 
@@ -273,7 +292,8 @@ class Deuces(FortyThieves):
 
     def _shuffleHook(self, cards):
         # move Twos to top of the Talon (i.e. first cards to be dealt)
-        return self._shuffleHookMoveToTop(cards, lambda c: (c.rank == 1, c.suit))
+        return self._shuffleHookMoveToTop(
+            cards, lambda c: (c.rank == 1, c.suit))
 
     def startGame(self):
         self.startDealSample()
@@ -298,7 +318,8 @@ class Corona(FortyThieves):
 
 
 class Quadrangle(Corona):
-    Foundation_Class = StackWrapper(SS_FoundationStack, mod=13, base_rank=NO_RANK)
+    Foundation_Class = StackWrapper(
+        SS_FoundationStack, mod=13, base_rank=NO_RANK)
     RowStack_Class = StackWrapper(SS_RowStack, mod=13)
 
     def startGame(self):
@@ -396,6 +417,7 @@ class NumberTwelve(NumberTen):
 
 class Roosevelt(Streets):
     DEAL = (0, 4)
+
     def createGame(self):
         Streets.createGame(self, rows=7)
 
@@ -417,7 +439,8 @@ class RedAndBlack(Streets):
 
     def _shuffleHook(self, cards):
         # move Aces to top of the Talon (i.e. first cards to be dealt)
-        return self._shuffleHookMoveToTop(cards, lambda c: (c.rank == 0, c.suit))
+        return self._shuffleHookMoveToTop(
+            cards, lambda c: (c.rank == 0, c.suit))
 
     def startGame(self):
         self.startDealSample()
@@ -449,9 +472,9 @@ class Indian(FortyThieves):
         FortyThieves.createGame(self, XCARDS=74)
 
     def shallHighlightMatch(self, stack1, card1, stack2, card2):
-        return (card1.suit != card2.suit
-                and (card1.rank + 1 == card2.rank
-                     or card2.rank + 1 == card1.rank))
+        return (card1.suit != card2.suit and
+                (card1.rank + 1 == card2.rank or
+                 card2.rank + 1 == card1.rank))
 
 
 class Midshipman(Indian):
@@ -500,7 +523,6 @@ class FinalBattle(DoubleRail):
         FortyThieves.createGame(self, rows=6)
 
 
-
 # ************************************************************************
 # * Octave
 # ************************************************************************
@@ -558,13 +580,13 @@ class Octave(Game):
         self.setSize(w, h)
 
         # create stacks
-        x, y = l.XM+l.XS/2, l.YM
+        x, y = l.XM+l.XS2, l.YM
         for i in range(8):
             s.foundations.append(SS_FoundationStack(x, y, self,
-                                 suit=int(i/2), max_cards=10))
+                                 suit=int(i//2), max_cards=10))
             x += l.XS
 
-        x, y = l.XM+l.XS/2, l.YM+l.YS
+        x, y = l.XM+l.XS//2, l.YM+l.YS
         for i in range(8):
             s.rows.append(AC_RowStack(x, y, self,
                                       base_rank=ANY_RANK, max_move=1))
@@ -592,9 +614,7 @@ class Octave(Game):
 
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
-        for i in range(2):
-            self.s.talon.dealRow(frames=0)
-        self.startDealSample()
+        self._startDealNumRows(2)
         self.s.talon.dealRow()
         self.s.talon.dealCards()          # deal first card to WasteStack
 
@@ -610,7 +630,8 @@ class Octave(Game):
     shallHighlightMatch = Game._shallHighlightMatch_AC
 
     def _autoDeal(self, sound=True):
-        ncards = len(self.s.waste.cards) + sum([len(i.cards) for i in self.s.reserves])
+        ncards = len(self.s.waste.cards) + sum(
+            [len(i.cards) for i in self.s.reserves])
         if ncards == 0:
             return self.dealCards(sound=sound)
         return 0
@@ -661,19 +682,14 @@ class FortunesFavor(Game):
 
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
         # move Aces to top of the Talon (i.e. first cards to be dealt)
         return self._shuffleHookMoveToTop(cards,
                                           lambda c: (c.rank == ACE, c.suit))
 
-
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
-        self.s.talon.dealCards()          # deal first card to WasteStack
-
+        self._startAndDealRowAndCards()
 
     def fillStack(self, stack):
         if len(stack.cards) == 0:
@@ -682,7 +698,6 @@ class FortunesFavor(Game):
             elif stack in self.s.rows and self.s.waste.cards:
                 self.s.waste.moveMove(1, stack)
 
-
     shallHighlightMatch = Game._shallHighlightMatch_SS
 
 
@@ -711,13 +726,13 @@ class Octagon(Game):
         i = 0
         for x, y in ((l.XM+w1,                    l.YM),
                      (l.XM+w1+l.XS,               l.YM),
-                     (l.XM+w1-2*l.XS-l.XS/2-l.XM, l.YM+1.5*l.YS),
-                     (l.XM+w1-l.XS-l.XS/2-l.XM,   l.YM+1.5*l.YS),
-                     (l.XM+w1+2*l.XS+l.XS/2+l.XM, l.YM+1.5*l.YS),
-                     (l.XM+w1+3*l.XS+l.XS/2+l.XM, l.YM+1.5*l.YS),
+                     (l.XM+w1-2*l.XS-l.XS//2-l.XM, l.YM+1.5*l.YS),
+                     (l.XM+w1-l.XS-l.XS//2-l.XM,   l.YM+1.5*l.YS),
+                     (l.XM+w1+2*l.XS+l.XS//2+l.XM, l.YM+1.5*l.YS),
+                     (l.XM+w1+3*l.XS+l.XS//2+l.XM, l.YM+1.5*l.YS),
                      (l.XM+w1,                    l.YM+3*l.YS),
                      (l.XM+w1+l.XS,               l.YM+3*l.YS),):
-            s.foundations.append(SS_FoundationStack(x, y, self, suit=i%4))
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=i % 4))
             i += 1
         x, y = l.XM+w1, l.YM+1.5*l.YS
         s.talon = WasteTalonStack(x, y, self, max_rounds=4)
@@ -729,11 +744,10 @@ class Octagon(Game):
 
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
         # move Aces to top of the Talon (i.e. first cards to be dealt)
-        return self._shuffleHookMoveToTop(cards,
-                   lambda c: (c.rank == ACE, (c.deck, c.suit)))
+        return self._shuffleHookMoveToTop(
+            cards, lambda c: (c.rank == ACE, (c.deck, c.suit)))
 
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
@@ -771,9 +785,9 @@ class Squadron(FortyThieves):
         l.createText(s.waste, 's')
         x += 2*l.XS
         for i in range(8):
-            s.foundations.append(SS_FoundationStack(x, y, self, suit=i/2))
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=i//2))
             x += l.XS
-        x, y = l.XM, l.YM+l.YS*3/2
+        x, y = l.XM, l.YM+l.YS*3//2
         for i in range(3):
             s.reserves.append(ReserveStack(x, y, self))
             y += l.YS
@@ -784,12 +798,9 @@ class Squadron(FortyThieves):
 
         l.defaultStackGroups()
 
-
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.reserves, frames=0)
-        for i in range(3):
-            self.s.talon.dealRow(frames=0)
-        self.startDealSample()
+        self._startDealNumRows(3)
         self.s.talon.dealRow()
         self.s.talon.dealCards()          # deal first card to WasteStack
 
@@ -810,8 +821,8 @@ class Waterloo(FortyThieves):
 
     def _shuffleHook(self, cards):
         # move Aces to top of the Talon (i.e. first cards to be dealt)
-        return self._shuffleHookMoveToTop(cards,
-                   lambda c: (c.rank == ACE, (c.deck, c.suit)))
+        return self._shuffleHookMoveToTop(
+            cards, lambda c: (c.rank == ACE, (c.deck, c.suit)))
 
     def startGame(self):
         self.startDealSample()
@@ -832,7 +843,7 @@ class Junction(Game):
     Foundation_Class = StackWrapper(DieRussische_Foundation, max_cards=8)
 
     def createGame(self, rows=7):
-        
+
         l, s = Layout(self), self.s
 
         self.setSize(l.XM+10*l.XS, l.YM+3*l.YS+12*l.YOFFSET)
@@ -842,11 +853,11 @@ class Junction(Game):
             x = l.XM+2*l.XS
             for j in range(8):
                 s.foundations.append(self.Foundation_Class(x, y, self,
-                                                           suit=j%4))
+                                                           suit=j % 4))
                 x += l.XS
             y += l.YS
 
-        x, y = l.XM+(10-rows)*l.XS/2, l.YM+2*l.YS
+        x, y = l.XM+(10-rows)*l.XS//2, l.YM+2*l.YS
         for i in range(rows):
             s.rows.append(AC_RowStack(x, y, self))
             x += l.XS
@@ -860,13 +871,11 @@ class Junction(Game):
 
         l.defaultStackGroups()
 
-
     def startGame(self):
         self.startDealSample()
         self.s.talon.dealRow()
         self.s.talon.dealCards()
 
-
     shallHighlightMatch = Game._shallHighlightMatch_AC
 
 
@@ -921,18 +930,18 @@ class TheSpark(Game):
         x, y = l.XM, l.YM
         for i in range(8):
             s.foundations.append(SS_FoundationStack(x, y, self,
-                                 suit=i/2, base_rank=KING, mod=13))
+                                 suit=i//2, base_rank=KING, mod=13))
             x += l.XS
         x, y = l.XM, l.YM+l.YS
         s.talon = TheSpark_Talon(x, y, self, max_rounds=1, num_deal=3)
         l.createText(s.talon, 'se')
         y += l.YS
-        for i in (0,1):
+        for i in (0, 1):
             stack = WasteStack(x, y, self)
             s.reserves.append(stack)
             l.createText(stack, 'se')
             y += l.YS
-        y = l.YM+l.YS*3/2
+        y = l.YM+l.YS*3//2
         for i in range(2):
             x = l.XM+2*l.XS
             for j in range(6):
@@ -944,19 +953,14 @@ class TheSpark(Game):
 
         l.defaultStackGroups()
 
-
     def _shuffleHook(self, cards):
         # move Aces to top of the Talon (i.e. first cards to be dealt)
         return self._shuffleHookMoveToTop(cards,
                                           lambda c: (c.rank == KING, c.suit))
 
-
     def startGame(self):
         self.s.talon.dealRow(rows=self.s.foundations, frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
-        self.s.talon.dealCards()          # deal first card to WasteStack
-
+        self._startAndDealRowAndCards()
 
     shallHighlightMatch = Game._shallHighlightMatch_SS
 
@@ -968,6 +972,7 @@ class TheSpark(Game):
 class DoubleGoldMine_RowStack(AC_RowStack):
     getBottomImage = Stack._getReserveBottomImage
 
+
 class DoubleGoldMine(Streets):
 
     RowStack_Class = DoubleGoldMine_RowStack
@@ -1001,7 +1006,7 @@ class Interchange(FortyThieves):
         FortyThieves.createGame(self, rows=7)
 
     def startGame(self):
-        for i in (0,1,2):
+        for i in (0, 1, 2):
             self.s.talon.dealRow(frames=0)
             self.s.talon.dealRow(flip=0, frames=0)
         self.startDealSample()
@@ -1033,11 +1038,7 @@ class FortyNine(Interchange):
     RowStack_Class = FortyNine_RowStack
 
     def startGame(self):
-        for i in range(6):
-            self.s.talon.dealRow(frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
-        self.s.talon.dealCards()
+        self._startDealNumRowsAndDealRowAndCards(6)
 
     shallHighlightMatch = Game._shallHighlightMatch_AC
 
@@ -1055,7 +1056,7 @@ class TripleInterchange(Interchange):
                                 max_rounds=UNLIMITED_REDEALS)
 
     def startGame(self):
-        for i in (0,1,2,3):
+        for i in (0, 1, 2, 3):
             self.s.talon.dealRow(frames=0)
             self.s.talon.dealRow(flip=0, frames=0)
         self.startDealSample()
@@ -1079,6 +1080,7 @@ class IndianPatience_RowStack(BO_RowStack):
             return len(self.cards) != 1
         return True
 
+
 class IndianPatience(Indian):
     RowStack_Class = IndianPatience_RowStack
 
@@ -1119,7 +1121,7 @@ class Floradora(Game):
         l.createText(s.waste, 's')
         x += l.XS
         for i in range(8):
-            s.foundations.append(SS_FoundationStack(x, y, self, suit=i%4,
+            s.foundations.append(SS_FoundationStack(x, y, self, suit=i % 4,
                                                     max_cards=12))
             x += l.XS
         x, y = l.XM, l.YM+l.YS+l.TEXT_HEIGHT
@@ -1133,11 +1135,7 @@ class Floradora(Game):
         l.defaultStackGroups()
 
     def startGame(self):
-        for i in range(5):
-            self.s.talon.dealRow(frames=0)
-        self.startDealSample()
-        self.s.talon.dealRow()
-        self.s.talon.dealCards()
+        self._startDealNumRowsAndDealRowAndCards(5)
 
     shallHighlightMatch = Game._shallHighlightMatch_RK
 
@@ -1150,7 +1148,8 @@ class BlindPatience_Hint(DefaultHint):
     SCORE_FLIP = 80000
 
     def shallMovePile(self, from_stack, to_stack, pile, rpile):
-        if from_stack is to_stack or not to_stack.acceptsCards(from_stack, pile):
+        if from_stack is to_stack or \
+                not to_stack.acceptsCards(from_stack, pile):
             return False
         #
         if len(rpile) == 0:
@@ -1225,12 +1224,12 @@ class BlindPatience(FortyThieves):
 class Foothold(FortyThieves):
     RowStack_Class = UD_AC_RowStack
     DEAL = (0, 5)
+
     def createGame(self):
         FortyThieves.createGame(self, rows=8, playcards=16)
     shallHighlightMatch = Game._shallHighlightMatch_AC
 
 
-
 # register the game
 registerGame(GameInfo(13, FortyThieves, "Forty Thieves",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL,
@@ -1260,14 +1259,15 @@ registerGame(GameInfo(76, Streets, "Streets",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(73, Maria, "Maria",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_BALANCED,
-                      altnames=("Maria Luisa",) ))
+                      altnames=("Maria Luisa",)))
 registerGame(GameInfo(70, NumberTen, "Number Ten",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(71, RankAndFile, "Rank and File",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_BALANCED,
-                      altnames=("Dress Parade") ))
+                      altnames=("Dress Parade")))
 registerGame(GameInfo(197, TripleLine, "Triple Line",
-                      GI.GT_FORTY_THIEVES | GI.GT_XORIGINAL, 2, 1, GI.SL_BALANCED))
+                      GI.GT_FORTY_THIEVES | GI.GT_XORIGINAL, 2, 1,
+                      GI.SL_BALANCED))
 registerGame(GameInfo(126, RedAndBlack, "Red and Black",        # was: 75
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(113, Zebra, "Zebra",
@@ -1277,7 +1277,8 @@ registerGame(GameInfo(69, Indian, "Indian",
 registerGame(GameInfo(74, Midshipman, "Midshipman",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(198, NapoleonsExile, "Napoleon's Exile",
-                      GI.GT_FORTY_THIEVES | GI.GT_XORIGINAL, 2, 0, GI.SL_BALANCED))
+                      GI.GT_FORTY_THIEVES | GI.GT_XORIGINAL, 2, 0,
+                      GI.SL_BALANCED))
 registerGame(GameInfo(131, DoubleRail, "Double Rail",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(199, SingleRail, "Single Rail",
@@ -1303,15 +1304,20 @@ registerGame(GameInfo(462, Josephine, "Josephine",
 registerGame(GameInfo(493, MarieRose, "Marie Rose",
                       GI.GT_FORTY_THIEVES, 3, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(503, BigStreets, "Big Streets",
-                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 3, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 3, 0,
+                      GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(504, NumberTwelve, "Number Twelve",
-                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 3, 0, GI.SL_BALANCED))
+                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 3, 0,
+                      GI.SL_BALANCED))
 registerGame(GameInfo(505, BigCourtyard, "Big Courtyard",
-                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 3, 0, GI.SL_BALANCED))
+                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 3, 0,
+                      GI.SL_BALANCED))
 registerGame(GameInfo(506, Express, "Express",
-                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 3, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 3, 0,
+                      GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(514, Carnation, "Carnation",
-                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 4, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 4, 0,
+                      GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(528, FinalBattle, "Final Battle",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(529, SanJuanHill, "San Juan Hill",
@@ -1320,11 +1326,12 @@ registerGame(GameInfo(540, Waterloo, "Waterloo",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_BALANCED))
 registerGame(GameInfo(556, Junction, "Junction",
                       GI.GT_FORTY_THIEVES, 4, 0, GI.SL_MOSTLY_SKILL,
-                      ranks=(0, 6, 7, 8, 9, 10, 11, 12) ))
+                      ranks=(0, 6, 7, 8, 9, 10, 11, 12)))
 registerGame(GameInfo(564, TheSpark, "The Spark",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_LUCK))
 registerGame(GameInfo(573, DoubleGoldMine, "Double Gold Mine",
-                      GI.GT_NUMERICA | GI.GT_ORIGINAL, 2, 0, GI.SL_MOSTLY_SKILL))
+                      GI.GT_NUMERICA | GI.GT_ORIGINAL, 2, 0,
+                      GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(574, Interchange, "Interchange",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(575, Unlimited, "Unlimited",
@@ -1350,5 +1357,5 @@ registerGame(GameInfo(683, FamousFifty, "Famous Fifty",
 registerGame(GameInfo(751, BlindPatience, "Blind Patience",
                       GI.GT_FORTY_THIEVES, 2, 0, GI.SL_MOSTLY_SKILL))
 registerGame(GameInfo(765, Foothold, "Foothold",
-                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 2, 0, GI.SL_MOSTLY_SKILL))
-
+                      GI.GT_FORTY_THIEVES | GI.GT_ORIGINAL, 2, 0,
+                      GI.SL_MOSTLY_SKILL))
